@@ -1,5 +1,4 @@
 from itertools import product
-from collections import defaultdict
 
 COMMANDS = {
     '9420': '',
@@ -1047,3 +1046,15 @@ INCONVERTIBLE_TO_ASCII_EXTENDED_CHARS_ASSOCIATION = {
      '└': ["+"],
      '┘': ["+"]
 }
+
+MID_ROW_CODES = [
+    "9120", "91a1", "91a2", "9123", "91a4", "9125", "9126",
+    "91a7", "91a8", "9129", "912a", "91ab", "912c", "91ad",
+    "97ae", "972f", "91ae", "912f", "94a8"
+]
+
+BACKGROUND_COLOR_CODES = [
+    "1020", "10a1", "10a2", "1023", "10a4", "1025", "1026",
+    "10a7", "10a8", "1029", "102a", "10ab", "102c", "10ad",
+    "10ae", "102f", "97ad"
+]
